package cd.casic.ci.common.pipeline.enums;

import lombok.AllArgsConstructor;
import lombok.Getter;

/**
 * @Author：mianbin
 * @Package：cd.casic.ci.common.pipeline.enums
 * @Project：ops-pro
 * @name：BuildStatus
 * @Date：2025/03/25 17:02
 * @Filename：BuildStatus
 * @description：Todo
 */
@Getter
@AllArgsConstructor
public enum BuildStatus {
    SUCCEED("succeed", true),
    FAILED("failed", true),
    CANCELED("canceled", true),
    RUNNING("running", true),
    TERMINATE("terminate", true),
    REVIEWING("reviewing", true),
    REVIEW_ABORT("reviewAbort", true),
    REVIEW_PROCESSED("reviewProcessed", true),
    HEARTBEAT_TIMEOUT("heartbeatTimeout", true),
    PREPARE_ENV("prepareEnv", true),
    UNEXEC("unexec", false),
    SKIP("skip", true),
    QUALITY_CHECK_FAIL("qualityCheckFail", true),
    QUEUE("queue", true),
    LOOP_WAITING("loopWaiting", true),
    CALL_WAITING("callWaiting", true),
    TRY_FINALLY("tryFinally", false),
    QUEUE_TIMEOUT("queueTimeout", true),
    EXEC_TIMEOUT("execTimeout", true),
    QUEUE_CACHE("queueCache", true),
    RETRY("retry", true),
    PAUSE("pause", true),
    STAGE_SUCCESS("stageSuccess", true),
    QUOTA_FAILED("quotaFailed", true),
    DEPENDENT_WAITING("dependentWaiting", true),
    QUALITY_CHECK_PASS("qualityCheckPass", true),
    QUALITY_CHECK_WAIT("qualityCheckWait", true),
    TRIGGER_REVIEWING("triggerReviewing", true),
    UNKNOWN("unknown", false);

    private final String statusName;
    private final boolean visible;

    public boolean isNeverRun() {
        return this == UNEXEC || this == TRIGGER_REVIEWING;
    }

    public boolean isFinish() {
        return isFailure() || isSuccess() || isCancel();
    }

    public boolean isFailure() {
        return this == FAILED || isPassiveStop() || isTimeout();
    }

    public boolean isSuccess() {
        return this == SUCCEED || this == SKIP || this == REVIEW_PROCESSED || this == QUALITY_CHECK_PASS;
    }

    public boolean isCancel() {
        return this == CANCELED;
    }

    public boolean isSkip() {
        return this == SKIP;
    }

    public boolean isTerminate() {
        return this == TERMINATE;
    }

    public boolean isRunning() {
        return this == RUNNING || this == LOOP_WAITING || this == REVIEWING || this == PREPARE_ENV || this == CALL_WAITING || this == PAUSE;
    }

    public boolean isReview() {
        return this == REVIEW_ABORT || this == REVIEW_PROCESSED;
    }

    public boolean isReadyToRun() {
        return this == QUEUE || this == QUEUE_CACHE || this == RETRY || this == DEPENDENT_WAITING;
    }

    public boolean isPassiveStop() {
        return this == TERMINATE || this == REVIEW_ABORT || this == QUALITY_CHECK_FAIL;
    }

    public boolean isPause() {
        return this == PAUSE;
    }

    public boolean isTimeout() {
        return this == QUEUE_TIMEOUT || this == EXEC_TIMEOUT || this == HEARTBEAT_TIMEOUT;
    }

    public static BuildStatus parse(String statusName) {
        try {
            return statusName == null ? UNKNOWN : BuildStatus.valueOf(statusName);
        } catch (Exception ignored) {
            return UNKNOWN;
        }
    }
}
