package cd.casic.ci.common.pipeline.pojo.element.agent;

import cd.casic.ci.common.pipeline.NameAndValue;
import cd.casic.ci.common.pipeline.enums.BuildScriptType;
import cd.casic.ci.common.pipeline.enums.CharsetType;
import cd.casic.ci.common.pipeline.pojo.element.Element;
import cd.casic.ci.common.pipeline.pojo.transfer.PreStep;
import com.alibaba.fastjson.JSONObject;
import io.swagger.v3.oas.annotations.media.Schema;
import lombok.NoArgsConstructor;

import java.net.URLEncoder;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @Author：mianbin
 * @Package：cd.casic.ci.common.pipeline.pojo.element.agent
 * @Project：ops-pro
 * @name：WindowsScriptElement
 * @Date：2025/03/26 16:44
 * @Filename：WindowsScriptElement
 * @description：Todo
 */
@NoArgsConstructor
@Schema(title = "脚本任务（windows环境）", description = WindowsScriptElement.classType)
public class WindowsScriptElement extends Element {
    public static final String classType = "windowsScript";

    @Schema(title = "任务名称", required = true)
    private String name = "执行Windows的bat脚本";
    @Schema(title = "id", required = false)
    private String id;
    @Schema(title = "状态", required = false)
    private String status;
    @Schema(title = "用户自定义ID", required = false)
    private String stepId;
    @Schema(title = "用户自定义环境变量（插件运行时写入环境）", required = false)
    private List<NameAndValue> customEnv;
    @Schema(title = "FAQ url链接", required = false)
    private String errorFAQUrl;
    @Schema(title = "脚本内容", required = true)
    private String script;
    @Schema(title = "脚本类型", required = true)
    private BuildScriptType scriptType;
    @Schema(title = "字符集类型", required = false)
    private CharsetType charsetType;

    @Override
    public Map<String, Object> genTaskParams() {
        Map<String, Object> mutableMap = super.genTaskParams();
        try {
            mutableMap.put("script", URLEncoder.encode(script, "UTF-8"));
        } catch (Exception e) {
            mutableMap.put("script", script);
        }
        return mutableMap;
    }

    public PreStep transferYaml(JSONObject defaultValue) {
        Map<String, Object> res = new HashMap<>();
        res.put("script", script);
        if (charsetType != null && !charsetType.equals(CharsetType.DEFAULT)) {
            res.put("charsetType", charsetType.name());
        }
        return new PreStep(
                name,
                stepId,
                getAtomCode() + "@" + getVersion(),
                res
        );
    }

    @Override
    public String getClassType() {
        return classType;
    }
}
