package cd.casic.ci.process.api.process.pojo.pipeline.record;

import cd.casic.ci.common.pipeline.container.Stage;
import cd.casic.ci.common.pipeline.enums.BuildRecordTimeStamp;
import cd.casic.ci.common.pipeline.enums.BuildStatus;
import cd.casic.ci.common.pipeline.pojo.time.BuildTimestampType;
import cd.casic.ci.process.api.process.pojo.app.StartBuildContext;
import io.swagger.v3.oas.annotations.media.Schema;
import lombok.AllArgsConstructor;
import lombok.Data;

import java.time.LocalDateTime;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @author by mianbin
 * @Classname BuildRecordStage
 * @Description TODO
 * @Date 2025/3/31 17:16
 */
@Data
@AllArgsConstructor
@Schema(title = "构建详情记录-插件任务")
public class BuildRecordStage {
    @Schema(title = "构建ID", required = true)
    private String buildId;
    @Schema(title = "项目ID", required = true)
    private String projectId;
    @Schema(title = "流水线ID", required = true)
    private String pipelineId;
    @Schema(title = "编排版本号", required = true)
    private int resourceVersion;
    @Schema(title = "步骤ID", required = true)
    private String stageId;
    @Schema(title = "执行次数", required = true)
    private int executeCount;
    @Schema(title = "步骤序号", required = true)
    private int stageSeq;
    @Schema(title = "执行变量", required = true)
    private Map<String, Object> stageVar;
    @Schema(title = "构建状态", required = false)
    private String status;
    @Schema(title = "开始时间", required = true)
    private LocalDateTime startTime;
    @Schema(title = "结束时间", required = true)
    private LocalDateTime endTime;
    @Schema(title = "业务时间戳集合", required = true)
    private Map<BuildTimestampType, BuildRecordTimeStamp> timestamps;

    public static void addRecords(List<BuildRecordStage> recordStages, Stage stage, StartBuildContext context, int stageIndex, BuildStatus buildStatus, List<BuildRecordContainer> containerBuildRecords, List<BuildRecordTask> taskBuildRecords) {
        recordStages.add(new BuildRecordStage(
                context.getBuildId(),
                context.getProjectId(),
                context.getPipelineId(),
                context.getResourceVersion(),
                stage.getId(),
                context.getExecuteCount(),
                stageIndex,
                new HashMap<>(),
                buildStatus != null ? buildStatus.name() : null,
                null,
                null,
                new HashMap<>()
        ));
        stage.getContainers().forEach(container -> {
            BuildRecordContainer.BuildRecordContainerHelper.addRecords(containerBuildRecords, stage.getId(), stage.stageEnabled(), container, context, buildStatus, taskBuildRecords);
        });
    }
}
