package cd.casic.pipeline.store.api.container;

import cd.casic.framework.commons.pojo.CommonResult;
import cd.casic.pipeline.store.pojo.app.ContainerAppEnv;
import cd.casic.pipeline.store.pojo.app.ContainerAppEnvCreate;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.tags.Tag;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@Tag(name = "OP_CONTAINER_APP_ENV", description = "OP-容器-编译环境变量")
@RestController
@RequestMapping("/op/pipeline/container/app/env")
public interface OpContainerAppEnvResource {

    @Operation(summary = "添加编译环境变量")
    @PostMapping("/")
    CommonResult<Boolean> addContainerAppEnv(
            @Parameter(description = "容器编译环境变量请求实体", required = true)
            ContainerAppEnvCreate containerAppEnvRequest
    );

    @Operation(summary = "根据ID删除编译环境变量")
    @DeleteMapping("/{id}")
    CommonResult<Boolean> deleteContainerAppEnvById(
            @Parameter(description = "编译环境变量ID", required = true)
            @PathVariable("id")
            int id
    );

    @Operation(summary = "更新编译环境变量")
    @PutMapping("/{id}")
    CommonResult<Boolean> updateContainerAppEnv(
            @Parameter(description = "编译环境变量ID", required = true)
            @PathVariable("id")
            int id,
            @Parameter(description = "容器编译环境变量请求实体", required = true)
            ContainerAppEnvCreate containerAppEnvRequest
    );

    @Operation(summary = "根据appId获取所有编译环境变量信息")
    @GetMapping("/list/{appId}")
    CommonResult<List<ContainerAppEnv>> listContainerAppEnvsByAppId(
            @Parameter(description = "编译环境ID", required = true)
            @PathVariable("appId")
            int appId
    );

    @Operation(summary = "根据ID获取编译环境变量信息")
    @GetMapping("/{id}")
    CommonResult<ContainerAppEnv> getContainerAppEnvById(
            @Parameter(description = "编译环境变量ID", required = true)
            @PathVariable("id")
            int id
    );
}