package cd.casic.pipeline.store.api.template;

import cd.casic.framework.commons.pojo.CommonResult;
import cd.casic.framework.commons.pojo.PageResult;
import cd.casic.pipeline.store.pojo.common.comment.StoreCommentInfo;
import cd.casic.pipeline.store.pojo.common.comment.StoreCommentRequest;
import cd.casic.pipeline.store.pojo.common.comment.StoreCommentScoreInfo;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.tags.Tag;
import org.springframework.web.bind.annotation.*;

import static cd.casic.ci.common.pipeline.constant.OpsHeader.AUTH_HEADER_USER_ID;

@Tag(name = "USER_MARKET_TEMPLATE_COMMENT", description = "模板-模板评论")
@RestController
@RequestMapping("/user/market/template/comment")
public interface UserTemplateCommentResource {

    @Operation(summary = "获取模板评论接口")
    @GetMapping("/comments/{commentId}")
    CommonResult<StoreCommentInfo> getStoreComment(
            @Parameter(description = "userId", required = true)
            @RequestHeader(AUTH_HEADER_USER_ID)
            String userId,
            @Parameter(description = "评论ID", required = true)
            @PathVariable("commentId")
            String commentId
    );

    @Operation(summary = "获取模板的评论列表")
    @GetMapping("/templateCodes/{templateCode}/comments")
    PageResult<StoreCommentInfo> getStoreComments(
            @Parameter(description = "userId", required = true)
            @RequestHeader(AUTH_HEADER_USER_ID)
            String userId,
            @Parameter(description = "模板代码", required = true)
            @PathVariable("templateCode")
            String templateCode,
            @Parameter(description = "页码", required = true)
            @RequestParam("page")
            Integer page,
            @Parameter(description = "每页数量", required = true)
            @RequestParam("pageSize")
            Integer pageSize
    );

    @Operation(summary = "获取模板的评分详情")
    @GetMapping("/score/templateCodes/{templateCode}")
    CommonResult<StoreCommentScoreInfo> getTemplateCommentScoreInfo(
            @Parameter(description = "模板代码", required = true)
            @PathVariable("templateCode")
            String templateCode
    );

    @Operation(summary = "新增模板评论")
    @PostMapping("/templateIds/{templateId}/templateCodes/{templateCode}/comment")
    CommonResult<StoreCommentInfo> addTemplateComment(
            @Parameter(description = "userId", required = true)
            @RequestHeader(AUTH_HEADER_USER_ID)
            String userId,
            @Parameter(description = "模板ID", required = true)
            @PathVariable("templateId")
            String templateId,
            @Parameter(description = "模板代码", required = true)
            @PathVariable("templateCode")
            String templateCode,
            @Parameter(description = "评论信息请求报文体", required = true)
            StoreCommentRequest storeCommentRequest
    );

    @Operation(summary = "更新模板评论")
    @PutMapping("/comments/{commentId}")
    CommonResult<Boolean> updateStoreComment(
            @Parameter(description = "userId", required = true)
            @RequestHeader(AUTH_HEADER_USER_ID)
            String userId,
            @Parameter(description = "评论ID", required = true)
            @PathVariable("commentId")
            String commentId,
            @Parameter(description = "评论信息请求报文体", required = true)
            StoreCommentRequest storeCommentRequest
    );

    @Operation(summary = "评论点赞/取消点赞")
    @PutMapping("/praise/{commentId}")
    CommonResult<Integer> updateStoreCommentPraiseCount(
            @Parameter(description = "userId", required = true)
            @RequestHeader(AUTH_HEADER_USER_ID)
            String userId,
            @Parameter(description = "评论ID", required = true)
            @PathVariable("commentId")
            String commentId
    );
}