package cd.casic.server.controller;

import cd.casic.ci.common.pipeline.req.pipeline.PipelineCreateReq;
import cd.casic.ci.common.pipeline.req.pipeline.PipelineQueryReq;
import cd.casic.ci.common.pipeline.req.pipeline.PipelineReq;
import cd.casic.ci.common.pipeline.req.pipeline.PipelineUpdateReq;
import cd.casic.ci.common.pipeline.resp.pipeline.PipelineFindResp;
import cd.casic.ci.common.pipeline.utils.PageResult;
import cd.casic.ci.process.process.service.pipeline.PipelineService;
import cd.casic.framework.commons.pojo.CommonResult;
import jakarta.annotation.Resource;
import jakarta.annotation.security.PermitAll;
import jakarta.validation.Valid;
import org.jetbrains.annotations.NotNull;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

/**
 * @ClassName PipelineController
 * @Author hopeli
 * @Date 2025/5/10 10:28
 * @Version 1.0
 */

@RestController
@RequestMapping("/pipeline")
public class PipelineController {

    @Resource
    private PipelineService pipelineService;

    @PermitAll
    @PostMapping(path="/createPipeline")
    public CommonResult<String> createPipeline(@RequestBody @Valid PipelineCreateReq pipelineReq){

        String pipelineId = pipelineService.createPipeline(pipelineReq);

        return CommonResult.success(pipelineId);
    }


    @PermitAll
    @PostMapping(path="/findPipelineList")
    public CommonResult<List<PipelineFindResp>> findPipelineList(@RequestBody @Valid PipelineQueryReq pipelineQueryReq){

        List<PipelineFindResp> respList = pipelineService.findPipelineList(pipelineQueryReq);

        return CommonResult.success(respList);
    }

    @PermitAll
    @PostMapping(path="/findPipelineById")
    public CommonResult<PipelineFindResp> findPipelineById(@RequestBody @Valid PipelineQueryReq pipelineQueryReq){

        PipelineFindResp resp = pipelineService.findPipelineById(pipelineQueryReq);

        return CommonResult.success(resp);
    }

    @PostMapping(path="/deletePipeline")
    public CommonResult<Void> deletePipeline(@RequestBody @Valid PipelineReq req){

        pipelineService.deletePipeline(req);

        return CommonResult.success();
    }


    @PostMapping(path="/updatePipeline")
    public CommonResult<Void> updatePipeline(@RequestBody @NotNull @Valid PipelineUpdateReq pipeline){

        pipelineService.updatePipeline(pipeline);

        return CommonResult.success();
    }


    @PostMapping(path="/findPipelinePage")
    public CommonResult<PageResult<PipelineFindResp>> findPipelinePage(@RequestBody @NotNull @Valid PipelineQueryReq query){

        PageResult<PipelineFindResp> pipelineRespPage = pipelineService.findPipelinePage(query);

        return CommonResult.success(pipelineRespPage);
    }




    @PostMapping(path="/pipelineClone")
    public CommonResult<Void> pipelineClone(@RequestBody @Valid PipelineReq req){
        pipelineService.pipelineClone(req);

        return CommonResult.success();
    }
}
